@@ -37,7 +37,7 @@ class MemoryRepository(LocalRepository):
         with self.filesystem.open(path, "wb") as f:
             pickle.dump(df, f)
 
-    def _read_dataframe(self, path, kind="pandas"):
+    def _read_dataframe(self, path, df_type="pandas"):
         """Reads the dataframe from the in-memory
         path defined by `path`.
         """
